Plan class

Plan model representing a subscription plan in the Outseta API

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

Plan({String? uid, DateTime? created, DateTime? updated, String? createdBy, String? updatedBy, String? name, String? description, String? billingTerm, int? billingTermCount, double? amount, double? setupFee, int? trialPeriodDays, bool? isActive, bool? isFree, bool? recurringChargeAgreementRequired, List? planAddOns, Map<String, dynamic>? customFields})
Creates a new Plan instance
const
Plan.fromJson(Map<String, dynamic> json)
Factory constructor that creates a Plan from JSON data
factory

Properties

amount double?
The amount for the plan
final
billingTerm String?
The billing term (e.g., 'Month', 'Year')
final
billingTermCount int?
The number of billing terms
final
created DateTime?
The date and time the model was created
finalinherited
createdBy String?
The user who created the model
finalinherited
customFields Map<String, dynamic>?
Custom fields associated with this plan
final
description String?
The description of the plan
final
hashCode int
The hash code for this object.
no setterinherited
isActive bool?
Whether the plan is active
final
isFree bool?
Whether the plan is free
final
name String?
The name of the plan
final
planAddOns List?
The add-ons associated with this plan
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
recurringChargeAgreementRequired bool?
Whether a recurring charge agreement is required
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setupFee double?
The setup fee for the plan
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
trialPeriodDays int?
The number of trial period days
final
uid String?
The unique identifier of the model
finalinherited
updated DateTime?
The date and time the model was last updated
finalinherited
updatedBy String?
The user who last updated the model
finalinherited

Methods

copyWith({String? uid, DateTime? created, DateTime? updated, String? createdBy, String? updatedBy, String? name, String? description, String? billingTerm, int? billingTermCount, double? amount, double? setupFee, int? trialPeriodDays, bool? isActive, bool? isFree, bool? recurringChargeAgreementRequired, List? planAddOns, Map<String, dynamic>? customFields}) Plan
Creates a copy of this plan with the given fields replaced with new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this plan instance to a JSON map
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited